<? include ("barry.inc"); ?>

<? createHeader("Device Compatibility List"); ?>

<? createSubHeader("Device Compatibility List"); ?>

<p>This list is intended as a rough guide and record of past success
when using Barry with various versions of the BlackBerry handheld.
It is not guaranteed to be complete, and is based on feedback from
users such as yourself.</p>

<hr/>

<p><b><i>Please note:</i></b> A very large majority of BlackBerry devices
work with Barry by default, and so a compatibility list like this is
somewhat redundant.  Please try Barry with your device, and
<? createLink("contact", "report"); ?>
any issues you may have.  Please keep in mind the
<? createLink("index", "Known Issues"); ?> on the main page when testing
and reporting.</p>

<hr/>

<p>If you wish to contribute a report, please send
it to the <? createLink("contact", "mailing list"); ?>.</p>

<table border="1">
<tr>
	<th>Device Model</th>
	<th>Firmware Version</th>
	<th>Barry Version</th>
	<th>Distro / Machine</th>
	<th>Backup/Restore Databases</th>
	<th>Device Charges?</th>
	<th>Reported By</th>
</tr>

<tr>
	<td>Storm 9530</td>
	<td>v4.7.0.48, v4.7.0.141, v4.7.0.151 (current)</td>
	<td>0.15-git20090710</td>
	<td>Debian Sid on Intel Core Duo 32 bits</td>
	<td>All.  Sync with 0.4x: Memos, Calendar, Address Book, Tasks</td>
	<td>Yes, bcharge</td>
	<td><a href="http://www.mail-archive.com/barry-devel@lists.sourceforge.net/msg02403.html">Nicolas Vivien</a></td>
</tr>

<tr>
	<td>...</td>
	<td><i>more to come as time permits...</i></td>
	<td>...</td>
	<td>...</td>
	<td>...</td>
	<td>...</td>
	<td>...</td>
</tr>

</table>

